summaryrefslogtreecommitdiffstats
path: root/quanta/treeviews/scripttreeview.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/treeviews/scripttreeview.h')
-rw-r--r--quanta/treeviews/scripttreeview.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/quanta/treeviews/scripttreeview.h b/quanta/treeviews/scripttreeview.h
index 9914c622..88f0e4cb 100644
--- a/quanta/treeviews/scripttreeview.h
+++ b/quanta/treeviews/scripttreeview.h
@@ -54,14 +54,14 @@ protected slots:
* displays the RBM
*
*
* @param listView KListView where the event comes from
*
* @param item TQListViewItem where the mousepointer is hovering
*
* @param point TQPoint coordinates of the event
*
*/
- virtual void slotMenu(KListView *listView, TQListViewItem *item, const TQPoint &point);
+ virtual void slotMenu(TDEListView *listView, TQListViewItem *item, const TQPoint &point);
/**
* slot of TQListView
@@ -212,8 +212,8 @@ private:
/**
* remember the menu for manipulation
*/
- KPopupMenu *m_fileMenu;
- KPopupMenu *m_folderMenu;
+ TDEPopupMenu *m_fileMenu;
+ TDEPopupMenu *m_folderMenu;
int m_downloadMenuId;
};
@@ -54,14 +54,14 @@ protected slots:
*
*
- * @param listView KListView where the event comes from
+ * @param listView TDEListView where the event comes from
*
* @param item TQListViewItem where the mousepointer is hovering